{
 "metadata": {
  "name": "",
  "signature": "sha256:bfd59549edd5664ed37bca5862d9a04c62d4eeca15904f765a067920636cac81"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%matplotlib inline\n",
      "import numpy as np\n",
      "import numpy.random as rnd\n",
      "import matplotlib.pyplot as plt\n",
      "import sys\n",
      "plt.rcParams['figure.figsize'] = 12, 8"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 1
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Path Integral Monte Carlo"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "...for a single 1d quantum harmonic oscillator with $m = \\hbar = \\omega = 1$."
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Potential:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def V(x):\n",
      "    return 0.5 * x**2"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "System configuration (= single worldline):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "class Config:\n",
      "    def __init__(self, worldline):\n",
      "        self.worldline = worldline\n",
      "        self.M = len(worldline)\n",
      "    \n",
      "    def estimate_V(self):\n",
      "        return np.average(V(self.worldline))\n",
      "    \n",
      "    def estimate_T(self, tau):\n",
      "        xs = self.worldline\n",
      "        diffs = np.ediff1d(xs, xs[-1] - xs[0])\n",
      "        return 0.5 / tau - 0.5 / tau**2 * np.average(diffs**2)\n",
      "    \n",
      "    def estimate_density_histogram(self, bins, range):\n",
      "        return np.histogram(self.worldline, bins, range)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Metropolis update based on displacing a randomly chosen bead by a random step within $\\pm$max_step_size:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def metropolis_update(config, tau, max_step_size):\n",
      "    \"\"\"Returns True on acceptance.\"\"\"\n",
      "    # choose random bead & position\n",
      "    j = rnd.randint(config.M)\n",
      "    x = config.worldline[j]\n",
      "    x_new = x + rnd.uniform(-max_step_size, max_step_size)\n",
      "    \n",
      "    # compute \"detailed balance ratio\"\n",
      "    x_prec, x_succ = config.worldline[j-1], config.worldline[(j+1)%config.M]\n",
      "    chi = np.exp(-0.5 * ((x_prec - x_new)**2 + (x_new - x_succ)**2 - (x_prec - x)**2 - (x - x_succ)**2) / tau - tau * (V(x_new) - V(x)))\n",
      "    \n",
      "    # accept?\n",
      "    if rnd.uniform() <= chi:\n",
      "        config.worldline[j] = x_new\n",
      "        return True\n",
      "    return False"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 4
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Metropolis sweep (= $M$ updates):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def metropolis_sweep(config, tau, max_step_size):\n",
      "    \"\"\"Returns acceptance ratio.\"\"\"\n",
      "    num_accepted = 0\n",
      "    for _ in range(config.M):\n",
      "        num_accepted += metropolis_update(config, tau, max_step_size)\n",
      "    return num_accepted / float(config.M)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 5
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Simulation parameters:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "beta = 10\n",
      "M = 100\n",
      "config = Config(rnd.uniform(low=-1, high=1, size=M))\n",
      "max_step_size = 0.5\n",
      "num_sample_sweeps = 2**20\n",
      "num_thermalization_sweeps = num_sample_sweeps / 2**3\n",
      "tau = beta / float(M)\n",
      "\n",
      "print \"time step:\", tau"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "time step: 0.1\n"
       ]
      }
     ],
     "prompt_number": 6
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Thermalize:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%%time\n",
      "rnd.seed(42)\n",
      "\n",
      "for _ in range(num_thermalization_sweeps):\n",
      "    metropolis_sweep(config, tau, max_step_size)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "Wall time: 2min 35s\n"
       ]
      }
     ],
     "prompt_number": 7
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Sample:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%%time\n",
      "samples_T = np.empty(num_sample_sweeps)\n",
      "samples_V = np.empty(num_sample_sweeps)\n",
      "acceptance_ratio = 0.0\n",
      "\n",
      "for i in range(num_sample_sweeps):\n",
      "    samples_T[i] = config.estimate_T(tau)\n",
      "    samples_V[i] = config.estimate_V()\n",
      "    acceptance_ratio += metropolis_sweep(config, tau, max_step_size)\n",
      "    if (i+1) % (num_sample_sweeps / 100) == 0: sys.stdout.write('.'); sys.stdout.flush()\n",
      "acceptance_ratio /= float(num_sample_sweeps)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "."
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "Wall time: 21min 28s\n"
       ]
      }
     ],
     "prompt_number": 8
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Analysis"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Acceptance ratio (should be close to $1/2$):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "acceptance_ratio"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 9,
       "text": [
        "0.5944153785707386"
       ]
      }
     ],
     "prompt_number": 9
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Estimate observables:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "mean_T = np.mean(samples_T)\n",
      "mean_V = np.mean(samples_V)\n",
      "print \"T =\", mean_T\n",
      "print \"V =\", mean_V\n",
      "print \"E = T + V =\", mean_T + mean_V\n",
      "print \"(exact value: %s)\" % (0.5 / np.tanh(0.5 * beta))"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "T = 0.252356102639\n",
        "V = 0.245187297172\n",
        "E = T + V = 0.497543399812\n",
        "(exact value: 0.500045401991)\n"
       ]
      }
     ],
     "prompt_number": 10
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Running means:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "steps = np.arange(1, num_sample_sweeps+1)\n",
      "means_T = np.cumsum(samples_T) / steps\n",
      "means_V = np.cumsum(samples_V) / steps\n",
      "\n",
      "plt.figure()\n",
      "plt.autoscale()\n",
      "plt.title('Running means of energy observables')\n",
      "plt.xlabel('MC steps')\n",
      "plt.ylabel('Energy')\n",
      "plt.plot(means_T, label=r\"$\\bar T_j$\", color=\"green\")\n",
      "plt.axhline(mean_T, label=r\"$\\bar T$\", color=\"green\", ls=\"--\")\n",
      "plt.plot(means_V, label=r\"$\\bar V_j$\", color=\"blue\")\n",
      "plt.axhline(mean_V, label=r\"$\\bar V$\", color=\"blue\", ls=\"--\")\n",
      "plt.ylim(0.22, 0.28)\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA8gAAAIwCAYAAABa5ELCAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nRK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x9b5bef0>"
       ]
      }
     ],
     "prompt_number": 11
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Naive Estimation of Error (which would work if the Markov chain generated independent samples):"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def error_naive(samples):\n",
      "    return np.std(samples, ddof=1) / np.sqrt(len(samples))\n",
      "\n",
      "print \"naive error for T:\", error_naive(samples_T)\n",
      "print \"naive error for V:\", error_naive(samples_V)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "naive error for T: 0.000663077262071\n",
        "naive error for V: 0.000107220099583\n"
       ]
      }
     ],
     "prompt_number": 12
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Binning Analysis"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def errors_binning(samples, min_bins=128):\n",
      "    l_max = int(round(np.log2(len(samples) / min_bins)))\n",
      "    assert min_bins * 2**l_max == len(samples)\n",
      "    errors = np.empty(l_max + 1)\n",
      "    for l in range(l_max + 1):\n",
      "        errors[l] = np.std(samples, ddof=1) / np.sqrt(len(samples))\n",
      "        samples = (samples[::2] + samples[1::2]) / 2.0\n",
      "    return errors\n",
      "\n",
      "plt.figure()\n",
      "plt.title('binning analysis')\n",
      "plt.xlabel('binning level')\n",
      "plt.ylabel('error estimate')\n",
      "plt.plot(errors_binning(samples_T[:2**15]), label='T (2^15 samples)', ls=\"--\", color=\"green\")\n",
      "plt.plot(errors_binning(samples_V[:2**15]), label='V (2^15 samples)', ls=\"--\", color=\"blue\")\n",
      "plt.plot(errors_binning(samples_T[:2**18]), label='T (2^18 samples)', ls=\"-.\", color=\"green\")\n",
      "plt.plot(errors_binning(samples_V[:2**18]), label='V (2^18 samples)', ls=\"-.\", color=\"blue\")\n",
      "plt.plot(errors_binning(samples_T), label='T (2^20 samples)', ls=\"-\", color=\"green\", lw=2)\n",
      "plt.plot(errors_binning(samples_V), label='V (2^20 samples)', ls=\"-\", color=\"blue\", lw=2)\n",
      "plt.legend()\n",
      "plt.show()\n",
      "\n",
      "print \"error estimate for T:\", errors_binning(samples_T)[-1]\n",
      "print \"error estimate for V:\", errors_binning(samples_V)[-1]"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAA78AAAIwCAYAAABOcdwjAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0xcecb2b0>"
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "error estimate for T: 0.00230471264854\n",
        "error estimate for V: 0.00222891322282\n"
       ]
      }
     ],
     "prompt_number": 13
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Estimate autocorrelation times:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def tau_int(errors):\n",
      "    return 0.5 * (errors[-1]**2 / errors[0]**2 - 1)\n",
      "\n",
      "print \"tau_int for V:\", tau_int(errors_binning(samples_V))\n",
      "print \"tau_int for T:\", tau_int(errors_binning(samples_T))"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "tau_int for V: 215.57469722\n",
        "tau_int for T: "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "5.54053359185\n"
       ]
      }
     ],
     "prompt_number": 14
    }
   ],
   "metadata": {}
  }
 ]
}